Lists
:::::::::::::::::::::::::::::::::::::::::::
.. index::
    single: List

.. toctree::
    :caption: Lists
    :maxdepth: 3

    sequence.rst
    mutable.rst
    traversing.rst
    listOperations.rst
    slice.rst
    listMethods.rst
    deleteElement.rst
    listFunctions.rst
    listsAndStrings.rst
    parsing.rst
    objectsValues.rst
    aliasing.rst
    listAsArgument.rst
    debugging.rst
    glossary.rst
    Exercises.rst
    MixedupCode.rst
    WriteCode.rst
    pogil.rst
